Mesa (master): radeonsi: don't apply the Z export bug workaround to Hainan

Marek Olšák mareko at kemper.freedesktop.org
Thu Dec 1 01:17:11 UTC 2016


Module: Mesa
Branch: master
Commit: da7453666aecd49e277a291c17dc7ef602643055
URL:    http://cgit.freedesktop.org/mesa/mesa/commit/?id=da7453666aecd49e277a291c17dc7ef602643055

Author: Marek Olšák <marek.olsak at amd.com>
Date:   Tue Nov 29 20:49:24 2016 +0100

radeonsi: don't apply the Z export bug workaround to Hainan

not needed

Reviewed-by: Nicolai Hähnle <nicolai.haehnle at amd.com>

---

 src/gallium/drivers/radeonsi/si_shader.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/src/gallium/drivers/radeonsi/si_shader.c b/src/gallium/drivers/radeonsi/si_shader.c
index ee2fce1..44a4dd2 100644
--- a/src/gallium/drivers/radeonsi/si_shader.c
+++ b/src/gallium/drivers/radeonsi/si_shader.c
@@ -2898,10 +2898,11 @@ static void si_export_mrt_z(struct lp_build_tgsi_context *bld_base,
 		}
 	}
 
 	/* SI (except OLAND) has a bug that it only looks
 	 * at the X writemask component. */
 	if (ctx->screen->b.chip_class == SI &&
-	    ctx->screen->b.family != CHIP_OLAND)
+	    ctx->screen->b.family != CHIP_OLAND &&
+	    ctx->screen->b.family != CHIP_HAINAN)
 		mask |= 0x1;
 
 	/* Specify which components to enable */
@@ -2898,10 +2898,11 @@ static void si_export_mrt_z(struct lp_build_tgsi_context *bld_base,
 	}
 
-	/* SI (except OLAND) has a bug that it only looks
+	/* SI (except OLAND and HAINAN) has a bug that it only looks
 	 * at the X writemask component. */
 	if (ctx->screen->b.chip_class == SI &&




More information about the mesa-commit mailing list